==> drd-8.x-3.0.tar.gz: drd/src/Plugin/Action/DomainsEnableAll.php <==
<?php

/**
 * @file
 * Contains \Drupal\drd\Plugin\Action\DomainsEnableAll.
 */

namespace Drupal\drd\Plugin\Action;

use Drupal\Core\Annotation\Action;
use Drupal\Core\Annotation\Translation;

/**
 * Provides a 'DomainsEnableAll' action.
 *
 * @Action(
 *  id = "drd_action_domains_enableall",
 *  label = @Translation("Enable all domains"),
 *  type = "drd_core",
 * )
 */
class DomainsEnableAll extends BaseCoreRemote {

  /**
   * @inheritdoc
   */
  public function executeAction($core) {
    if (empty($core)) {
      return FALSE;
    }

    // Get drush and drupalconsole settings from host
    $drush = $core->getHost()->getDrush();
    $drupalconsole = $core->getHost()->getDrupalConsole();
    if (empty($drush) && empty($drupalconsole)) {
      return FALSE;
    }
    $this->setActionArgument('drush', $drush);
    $this->setActionArgument('drupalconsole', $drupalconsole);

    // Get all disabled domains from same core
    $domains = $core->getDomains(['installed' => 0]);
    if (empty($domains)) {
      return TRUE;
    }
    $urls = [];
    $local = [];
    foreach ($domains as $domain) {
      $url = $domain->buildUrl()->toString();
      $urls[$url] = $domain->getRemoteSetupToken(FALSE);
      $local[$url] = $domain;
    }
    $this->setActionArgument('urls', $urls);

    // Submit command to remote domain
    $response = parent::executeAction($core);
    if ($response) {
      foreach ($response as $url) {
        /** @var \Drupal\drd\Entity\DomainInterface $domain */
        $domain = $local[$url];
        $domain->set('installed', 1);
        $domain->save();
        $domain->remoteInfo();
      }
      return TRUE;
    }
    return FALSE;
  }

}

==> drd-8.x-3.5.tar.gz: drd/src/Plugin/Action/DomainsEnableAll.php <==
<?php

namespace Drupal\drd\Plugin\Action;

use Drupal\drd\Entity\DomainInterface;

/**
 * Provides a 'DomainsEnableAll' action.
 *
 * @Action(
 *  id = "drd_action_domains_enableall",
 *  label = @Translation("Enable all domains"),
 *  type = "drd_core",
 * )
 */
class DomainsEnableAll extends BaseCoreRemote {

  /**
   * @inheritdoc
   */
  public function executeAction($core) {
    if (empty($core)) {
      return FALSE;
    }

    // Get drush and drupalconsole settings from host
    $drush = $core->getHost()->getDrush();
    $drupalconsole = $core->getHost()->getDrupalConsole();
    if (empty($drush) && empty($drupalconsole)) {
      return FALSE;
    }
    $this->setActionArgument('drush', $drush);
    $this->setActionArgument('drupalconsole', $drupalconsole);

    // Get all disabled domains from same core
    $domains = $core->getDomains(['installed' => 0]);
    if (empty($domains)) {
      return TRUE;
    }
    $urls = [];
    $local = [];
    foreach ($domains as $domain) {
      $url = $domain->buildUrl()->toString(TRUE)->getGeneratedUrl();
      $urls[$url] = $domain->getRemoteSetupToken(FALSE);
      $local[$url] = $domain;
    }
    $this->setActionArgument('urls', $urls);

    // Submit command to remote domain
    $response = parent::executeAction($core);
    if ($response) {
      foreach ($response as $url) {
        /** @var DomainInterface $domain */
        $domain = $local[$url];
        $domain->set('installed', 1);
        $domain->save();
        $domain->remoteInfo();
      }
      return TRUE;
    }
    return FALSE;
  }

}
